package com.miaxis.pc.controller;

import com.miaxis.common.constant.Constants;
import java.util.List;
import java.util.Arrays;
import io.swagger.annotations.*;
import com.miaxis.common.core.domain.Response;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.ModelAttribute;
import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.order.domain.OrderItems;
import com.miaxis.order.service.IOrderItemsService;
import com.miaxis.common.utils.poi.ExcelUtil;
import com.miaxis.common.core.page.ResponsePageInfo;

/**
 * 【订单详情】Controller
 *
 * @author miaxis
 * @date 2023-11-17
 */
@RestController
@RequestMapping("/order/items")
@Api(tags={"【pc-订单详情】"})
public class OrderItemsController extends BaseController{
    @Autowired
    private IOrderItemsService orderItemsService;

    /**
     * 查询订单详情列表
     */
    @PreAuthorize("@ss.hasPermi('order:items:list')")
    @GetMapping("/list")
    @ApiOperation("查询订单详情列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<OrderItems> list(@ModelAttribute OrderItems orderItems){
        startPage();
        List<OrderItems> list = orderItemsService.selectOrderItemsList(orderItems);
        return toResponsePageInfo(list);
    }

    /**
     * 导出订单详情列表
     */
    @PreAuthorize("@ss.hasPermi('order:items:export')")
    @Log(title = "订单详情", businessType = BusinessTypeEnum.EXPORT)
    @GetMapping("/export")
    @ApiOperation("导出订单详情列表Excel")
    public Response<String> export(@ModelAttribute OrderItems orderItems){
        List<OrderItems> list = orderItemsService.selectOrderItemsList(orderItems);
        ExcelUtil<OrderItems> util = new ExcelUtil<OrderItems>(OrderItems.class);
        return util.exportExcel(list, "items");
    }

    /**
     * 获取订单详情详细信息
     */
    @PreAuthorize("@ss.hasPermi('order:items:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取订单详情详细信息")
    public Response<OrderItems> getInfo(
            @ApiParam(name = "id", value = "订单详情参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(orderItemsService.getById(id));
    }

    /**
     * 新增订单详情
     */
    @PreAuthorize("@ss.hasPermi('order:items:add')")
    @Log(title = "订单详情", businessType = BusinessTypeEnum.INSERT)
    @PostMapping
    @ApiOperation("新增订单详情")
    public Response<Integer> add(@RequestBody OrderItems orderItems){
        return toResponse(orderItemsService.save(orderItems) ? 1 : 0);
    }

    /**
     * 修改订单详情
     */
    @PreAuthorize("@ss.hasPermi('order:items:edit')")
    @Log(title = "订单详情", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改订单详情")
    public Response<Integer> edit(@RequestBody OrderItems orderItems){
        return toResponse(orderItemsService.updateById(orderItems) ? 1 : 0);
    }

    /**
     * 删除订单详情
     */
    @PreAuthorize("@ss.hasPermi('order:items:remove')")
    @Log(title = "订单详情", businessType = BusinessTypeEnum.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除订单详情")
    public  Response<Integer> remove(
            @ApiParam(name = "ids", value = "订单详情ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return toResponse(orderItemsService.removeByIds(Arrays.asList(ids)) ? 1 : 0);
    }
}
